function [ H,C1,alpha ] = DifferenceStructure( field,low,high )
%field is a two dimensional array
%low and high define the bounds over which the function is fit, which
%changes the values of the parameters
%This function uses reversed series to find H,C1,and alpha
[num,dim]=size(field);
qmax=21;
delq=0.1;
qeps=0.0001;
%With these parameters moments are caluculated every 0.1 from 0 to q=2
%qeps added to avoid exponenting to zero power(if data contains zero values)
qtab=qeps:delq:delq*qmax+qeps-delq;
points=floor(20*log10(dim));
i=1:points;
tab=floor(10.^(i./20));
ddelt=unique(tab);
coord=log10(ddelt);
%coord is log10 values of lags, i.e the lambda values
points=length(ddelt);
moms=zeros(points,qmax);
for j=1:num
    for y=1:points
        R=field(j,:);
        RR=wrev(R);
        %Reversing the series for better large lag statistics
        delt=ddelt(y);
        Rdelt=circshift(R,[0,delt]);
        delR=abs(R-Rdelt);
        RRdelt=circshift(RR,[0,delt]);
        delRR=abs(RR-RRdelt);
        take1=delR(delt+1:delt:dim);
        take2=delRR(delt+1:delt:dim);
        tt=[take1,take2];
        mat=zeros(length(tt),qmax);
        for i=1:length(tt)
            mat(i,:)=tt(i).^qtab;
        end
            M=mean(mat);
            moms(y,:)=M;
    end
end
moms=moms';
moms=log10(moms./num);
p=zeros(2,qmax);
for q=1:qmax
T=cat(1,coord,moms(q,:))';
take=T(low:high,1:2);
x=take(:,1);
y=take(:,2);
f=polyfit(x,y,1);
p(1,q)=f(1);
p(2,q)=f(2);
end
inter=p(2,:);
hqneg=p(1,:);
x=coord(low):0.1:coord(high);
figure
hold on
for j=1:qmax,
    y=inter(j)+hqneg(j)*x;
    grref(j)=plot(x,y);
end
hold off

ColOrd=get(gca,'ColorOrder');
[m,n]=size(ColOrd);
hold on
for k=1:qmax,
    ColRow=rem(k,m);
    if ColRow==0
        ColRow=m;
    end
    Col=ColOrd(ColRow,:);
    T=cat(1,coord,moms(k,:))';
    gr(k)=plot(T(:,1),T(:,2),'Color',Col);
    xlabel('Log_{10} \lambda')
    ylabel('Log_{10} M')
end
hold off
axis normal
%Colors each line on the plot uniquely

figure
Q=1:qmax;
psi=[qtab(Q);hqneg(Q)];
grpsi=plot(psi(1,:),psi(2,:));
xlabel('q');
ylabel('\xi (q)');

tK=psi';
ttK=tK(9:13,1:2);
ft=polyfit(ttK(:,1),ttK(:,2),2);
H=ft(1)+ft(2)+ft(3);
C1=H-2*ft(1)-ft(2);
alpha=-2*ft(1)/C1;

end


